@@ -47,7 +47,7 @@ where
 
         // We will inline if possible.
         if let Pat::Ident(i) = &var.name {
-            if i.id.sym == *"arguments" {
+            if i.id.sym == js_word!("arguments") {
                 return;
             }
             if self.options.top_retain.contains(&i.id.sym) {
@@ -185,7 +185,7 @@ where
                             var.span = var.span.apply_mark(self.marks.non_top_level);
                         }
 
-                        self.lits.insert(i.to_id(), init.take());
+                        self.vars.lits.insert(i.to_id(), init.take());
 
                         var.name.take();
                     } else if self.options.inline != 0 || self.options.reduce_vars {
@@ -197,7 +197,7 @@ where
 
                         self.mode.store(i.to_id(), &*init);
 
-                        self.lits.insert(i.to_id(), init.clone());
+                        self.vars.lits.insert(i.to_id(), init.clone());
                     }
                     return;
                 }
@@ -294,7 +294,7 @@ where
                         i.id
                     );
                     self.changed = true;
-                    self.vars_for_inlining.insert(i.to_id(), init.take());
+                    self.vars.vars_for_inlining.insert(i.to_id(), init.take());
                 }
             }
         }
@@ -479,7 +479,7 @@ where
                                     return;
                                 }
 
-                                self.simple_functions.insert(
+                                self.vars.simple_functions.insert(
                                     i.to_id(),
                                     match decl {
                                         Decl::Fn(f) => Box::new(Expr::Fn(FnExpr {
@@ -559,7 +559,7 @@ where
                     }
                 };
 
-                self.vars_for_inlining.insert(i.to_id(), e);
+                self.vars.vars_for_inlining.insert(i.to_id(), e);
             } else {
                 if cfg!(feature = "debug") {
                     tracing::trace!("inline: [x] Usage: {:?}", usage);
@@ -573,11 +573,12 @@ where
         if let Expr::Ident(i) = e {
             //
             if let Some(value) = self
+                .vars
                 .lits
                 .get(&i.to_id())
                 .or_else(|| {
                     if self.ctx.is_callee {
-                        self.simple_functions.get(&i.to_id())
+                        self.vars.simple_functions.get(&i.to_id())
                     } else {
                         None
                     }
@@ -615,7 +616,7 @@ where
             }
 
             // Check without cloning
-            if let Some(value) = self.vars_for_inlining.get(&i.to_id()) {
+            if let Some(value) = self.vars.vars_for_inlining.get(&i.to_id()) {
                 if self.ctx.is_exact_lhs_of_assign && !is_valid_for_lhs(value) {
                     return;
                 }
@@ -627,7 +628,7 @@ where
                 }
             }
 
-            if let Some(value) = self.vars_for_inlining.remove(&i.to_id()) {
+            if let Some(value) = self.vars.vars_for_inlining.remove(&i.to_id()) {
                 self.changed = true;
                 tracing::debug!(
                     "inline: Replacing '{}{:?}' with an expression",
